==> digikam-3.0.0-beta2.tar.bz2: digikam-3.0.0-beta2/extra/kipi-plugins/kopete/kipiplugin_kopete.desktop.cmake <==
[Desktop Entry]
Name=Instant Messaging Export
Name[bg]=Изнасяне в моментни съобщения
Name[bs]=Izvoz za instant poruke
Name[ca]=Exportador a missatgeria instantània
Name[ca@valencia]=Exportació a missatgeria instantània
Name[cs]=Export pro Instant Messaging
Name[da]=Eksport til instant messaging
Name[de]=Instant-Messaging-Export
Name[el]=Εξαγωγή άμεσου μηνύματος
Name[en_GB]=Instant Messaging Export
Name[es]=Exportación para Mensajería Instantánea
Name[et]=Kiirsuhtluse import
Name[gl]=Exportación a mensaxaría instantánea
Name[hu]=Azonnali üzenetküldő exportálás
Name[is]=Skyndiskilaboðasendingar
Name[it]=Esportazione a messaggistica
Name[km]=នាំចេញ​កា​រផ្ញើសារ​បន្ទាន់
Name[nb]=Lynmeldingseksport
Name[nl]=Exporteren van Instant Messaging
Name[pl]=Eksport do komunikatora internetowego
Name[pt]=Exportação para Mensagens Instantâneas
Name[pt_BR]=Exportar mensagens instantâneas
Name[ro]=Export către mesagerie instantanee
Name[ru]=Экспорт в сеть обмена мгновенными сообщениями
Name[sl]=Izvoz hipnih sporočil
Name[sv]=Export som direktmeddelande
Name[uk]=Експорт до мережі обміну повідомленнями
Name[x-test]=xxInstant Messaging Exportxx
Name[zh_CN]=即时消息导出
Name[zh_TW]=即時訊息匯出
Comment=A tool to export images to an instant messaging contact
Comment[bg]=Инструмент за изнасяне на изображения към контакт в моментни съобщения
Comment[bs]=Alat za izvoz slika za kontakte za instant poruke
Comment[ca]=Una eina per exportar imatges a un contacte de missatgeria instantània
Comment[ca@valencia]=Una eina per exportar imatges a un contacte de missatgeria instantània
Comment[cs]=Nástroj pro export obrázků do kontaktu na IM
Comment[da]=Et værktøj til at eksportere billeder til en instant messaging-kontakt
Comment[de]=Ein Werkzeug, um Bilder zu einem Instant-Messaging-Kontakt zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια επαφή άμεσου μηνύματος
Comment[en_GB]=A tool to export images to an instant messaging contact
Comment[es]=Una herramienta para exportar imágenes a un contacto de mensajería instantánea
Comment[et]=Tööriist piltide eksportimiseks kiirsuhtluskontaktile
Comment[gl]=Unha ferramenta para exportar imaxes a un contacto de mensaxaría instantánea
Comment[hu]=Egy eszköz képek exportálásához egy azonnali üzenetküldő partnernek
Comment[is]=Verkfæri til að senda myndir til tengiliðs í snarskilaboðaforriti
Comment[it]=Uno strumento per esportare immagini a un contatto di messaggistica
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ​កាន់ទំនាក់ទំនង​ផ្ញើសារ​បន្ទាន់
Comment[nb]=Et verktøy for å eksportere bilder til en lynmeldingskontakt
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar een contactpersoon in Instant Messaging
Comment[pl]=Narzędzie do eksportowania obrazów do kontaktu komunikatora internetowego
Comment[pt]=Uma ferramenta para exportar imagens para um contacto de mensagens instantâneas
Comment[pt_BR]=Uma ferramenta para exportar imagens para um contato de mensagens instantâneas
Comment[ro]=O unealtă de exportat imagini unui contact din mesageria instantanee
Comment[ru]=Инструмент для экспорта изображений в сеть обмена мгновенными сообщениями
Comment[sl]=Orodje za izvoz slik do stika v hipnem sporočanju
Comment[sv]=Ett verktyg för att exportera bilder till en direktmeddelandekontakt
Comment[uk]=Інструмент для експорту зображення до контакту мережі миттєвого обміну повідомленнями
Comment[x-test]=xxA tool to export images to an instant messaging contactxx
Comment[zh_TW]=匯出影像到即時訊息聯絡人的工具
Type=Service
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_kopete
Icon=kopete
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Pau Garcia i Quiles, pgquiles@elpauer.org

==> digikam-4.0.0-beta2.tar.bz2: digikam-4.0.0-beta2/extra/kipi-plugins/kopete/kipiplugin_kopete.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Instant Messaging Export
Name=Instant Messaging Export
Name[bg]=Изнасяне в моментни съобщения
Name[bs]=Izvoz za instant poruke
Name[ca]=Exportador a missatgeria instantània
Name[ca@valencia]=Exportador a missatgeria instantània
Name[cs]=Export pro Instant Messaging
Name[da]=Eksport til instant messaging
Name[de]=Instant-Messaging-Export
Name[el]=Εξαγωγή άμεσου μηνύματος
Name[en_GB]=Instant Messaging Export
Name[es]=Exportación para Mensajería Instantánea
Name[et]=Kiirsuhtluse import
Name[fr]=Exportation vers la messagerie instantanée
Name[gl]=Exportación a mensaxaría instantánea
Name[hu]=Azonnali üzenetküldő exportálás
Name[is]=Skyndiskilaboðasendingar
Name[it]=Esportazione a messaggistica
Name[km]=នាំចេញ​កា​រផ្ញើសារ​បន្ទាន់
Name[nb]=Lynmeldingseksport
Name[nl]=Exporteren van Instant Messaging
Name[pl]=Eksport do komunikatora internetowego
Name[pt]=Exportação para Mensagens Instantâneas
Name[pt_BR]=Exportar mensagens instantâneas
Name[ro]=Export către mesagerie instantanee
Name[ru]=Экспорт в сеть обмена мгновенными сообщениями
Name[sk]=Export instant messagingu
Name[sl]=Izvoz hipnih sporočil
Name[sv]=Export som direktmeddelande
Name[tr]=Anında Mesajlaşma Aktarımı
Name[uk]=Експорт до мережі обміну повідомленнями
Name[x-test]=xxInstant Messaging Exportxx
Name[zh_CN]=即时消息导出
Name[zh_TW]=即時訊息匯出
Comment=A tool to export images to an instant messaging contact
Comment[bg]=Инструмент за изнасяне на изображения към контакт в моментни съобщения
Comment[bs]=Alat za izvoz slika za kontakte za instant poruke
Comment[ca]=Una eina per exportar imatges a un contacte de missatgeria instantània
Comment[ca@valencia]=Una eina per exportar imatges a un contacte de missatgeria instantània
Comment[cs]=Nástroj pro export obrázků do kontaktu na IM
Comment[da]=Et værktøj til at eksportere billeder til en instant messaging-kontakt
Comment[de]=Ein Werkzeug, um Bilder zu einem Instant-Messaging-Kontakt zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια επαφή άμεσου μηνύματος
Comment[en_GB]=A tool to export images to an instant messaging contact
Comment[es]=Una herramienta para exportar imágenes a un contacto de mensajería instantánea
Comment[et]=Tööriist piltide eksportimiseks kiirsuhtluskontaktile
Comment[fr]=Outil d'exportation d'images vers un contact de messagerie instantanée
Comment[gl]=Unha ferramenta para exportar imaxes a un contacto de mensaxaría instantánea
Comment[hu]=Egy eszköz képek exportálásához egy azonnali üzenetküldő partnernek
Comment[is]=Verkfæri til að senda myndir til tengiliðs í snarskilaboðaforriti
Comment[it]=Uno strumento per esportare immagini a un contatto di messaggistica
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ​កាន់ទំនាក់ទំនង​ផ្ញើសារ​បន្ទាន់
Comment[nb]=Et verktøy for å eksportere bilder til en lynmeldingskontakt
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar een contactpersoon in Instant Messaging
Comment[pl]=Narzędzie do eksportowania obrazów do kontaktu komunikatora internetowego
Comment[pt]=Uma ferramenta para exportar imagens para um contacto de mensagens instantâneas
Comment[pt_BR]=Uma ferramenta para exportar imagens para um contato de mensagens instantâneas
Comment[ro]=O unealtă de exportat imagini unui contact din mesageria instantanee
Comment[ru]=Инструмент для экспорта изображений в сеть обмена мгновенными сообщениями
Comment[sl]=Orodje za izvoz slik do stika v hipnem sporočanju
Comment[sv]=Ett verktyg för att exportera bilder till en direktmeddelandekontakt
Comment[tr]=Resimleri bir anlış mesajlaşma kişisine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображення до контакту мережі миттєвого обміну повідомленнями
Comment[x-test]=xxA tool to export images to an instant messaging contactxx
Comment[zh_TW]=匯出影像到即時訊息聯絡人的工具
Type=Service
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_kopete
Icon=kopete
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Pau Garcia i Quiles, pgquiles@elpauer.org
